# Scarecrow
Scarecrow offers low code web development for data science.

## Demo
[screenshots]

## Getting started

## What is Scarecrow?
Scarecrow offers a free and fully customisationbale framework for building data
science apps, which works out of the box with as much customisation as you need.
There are many frameworks for web development, some based on Python. There are
many frameworks and products for data analysis and visualisation, and some for
data science models. However, Scarecrow offers significant advantages over these
existing technologies:
* Python-based frameworks require additional learning: even if you understand
Python and its ecosystem, you still need to learn more about HTML, CSS, HTTP
requests, and routing infrastructure.
* Existing apps for data science that are written and run as a Python file
offer limited support for infrstructure like multiple pages, user
authentication, and session tracking.
* Existing no-code solutions for rapid web development offer limited access to
source code and personalisation, or they require significant membership fees.

## Is Scarecrow what you're looking for?
Scarecrow is built in Python, HTML, CSS, and SQL. It draws on a range of
Python libraries - including those serving Flask functionality, and machine
learning modelling and visualisation with Sklearn, Tensorflow, Pandas,
Matplotlib, and Seaborn. At its core, a Scarecrow app it is built around a
Flask web application. This means HTTP routing determined by a Python app file,
leading to pages built on HTML templastes and formatted with CSS. It also
incorporates databases which are addressed through SQL.

## What else can you do with Scarecrow?
As a user, you don't need to be an expert in any of the languages or libraries
used for Scarecrow, but you are free to customise your Scarecrow app if you know
how to use them. The base apps don't integrate and JavaScript, so they're simple
and predictable, but there's nothing stopping you from adding some JavaScript
elements into your Scarecrow app.

## Goals and future milestones

## Further documentation (links)

## How can you contribute?
Scarecrow was established by Michael Hayman, who is fully responsible for its
development and maintenance. If you would like to contribute to Scarecrow,
please email mdghayman@gmail.com to share your proposal and your background.

## License
Copyright (c) 2021 Michael Hayman, under the MIT License
